@@ -158,7 +158,7 @@
 		return;
 	NJBQueueItem *copyFile = [[NJBQueueItem alloc] initWithTarget:theNJB withSelector:@selector(downloadFile:) withObject:dataFile];
 	[copyFile setStatus:STATUS_DOWNLOADING_FILE];
-	NSString *description = [NSString stringWithFormat:@"Downloading file '%@'", [dataFile filename]];
+	NSString *description = [NSString stringWithFormat:NSLocalizedString(@"Downloading file '%@'", nil), [dataFile filename]];
 	[self addToQueue:copyFile withSubItems:nil withDescription:description];
 	[copyFile release];
 	
@@ -238,7 +238,7 @@
 	
 	[copyFile cancelItemIfFail:addToList];
 	
-	NSString *description = [NSString stringWithFormat:@"Uploading file '%@'", [dataFile filename]];
+	NSString *description = [NSString stringWithFormat:NSLocalizedString(@"Uploading file '%@'", nil), [dataFile filename]];
 	[self addToQueue:copyFile withSubItems:[NSArray arrayWithObject:addToList] withDescription:description];
 	
 	[copyFile release];
@@ -285,7 +285,7 @@
 		if (removeFromParent != nil)
 			[deleteFile cancelItemIfFail:removeFromParent];
 	
-		NSString *description = [NSString stringWithFormat:@"Deleting file '%@'", [item description]];
+		NSString *description = [NSString stringWithFormat:NSLocalizedString(@"Deleting file '%@'", nil), [item description]];
 		if (removeFromParent != nil)
 			[self addToQueue:deleteFile withSubItems:[NSArray arrayWithObjects:removeFromParent, reloadNJBDirs, nil] withDescription:description];
 		else
@@ -406,7 +406,7 @@
 		
 	[createFolder cancelItemIfFail:addToList];
 	
-	NSString *description = [NSString stringWithFormat:@"Creating folder '%@'", newFolderName];
+	NSString *description = [NSString stringWithFormat:NSLocalizedString(@"Creating folder '%@'", nil), newFolderName];
 	[self addToQueue:createFolder withSubItems:[NSArray arrayWithObjects:addToList, nil] withDescription:description];
 		
 	[createFolder release];
@@ -456,7 +456,10 @@
  */
 - (void)deleteFromNJB
 {
-	int result = NSRunAlertPanel(@"File Deletion", @"Are you sure you want to delete the selected items off the NJB?", @"No", @"Yes", nil);
+	int result = NSRunAlertPanel(NSLocalizedString(@"File Deletion", nil),
+															 NSLocalizedString(@"Are you sure you want to delete the selected items off the NJB?", nil),
+															 NSLocalizedString(@"No", nil), 
+															 NSLocalizedString(@"Yes", nil), nil);
 	if (result == NSAlertDefaultReturn)
 		return;
 	
