@@ -27,6 +27,7 @@
 	// we know the cache should not be used
 	BOOL downloadingTracks;
 	njb_t njbs[NJB_MAX_DEVICES];
+	BOOL turbo;
 	
 	NSString *deviceString;
 	NSString *firmwareVersionString;
@@ -74,6 +75,7 @@
 - (void)storeDeviceVersionString;
 - (int)batteryLevel;
 - (NSString *)batteryStatus;
+- (void)setTurbo:(BOOL) newTurbo;
 
 int progress (u_int64_t sent, u_int64_t total, const char* buf, unsigned len, void *data);
 
