@@ -151,14 +151,14 @@ StatusDisplayer *statusDisplayerGlobal;
 	if (NJB_Discover(njbs, 0, &n) == -1)
 	{
 		fprintf(stderr, "could not locate any jukeboxes\n");
-		return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:@"Could not discover any jukeboxes"] autorelease];
+		return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:NSLocalizedString(@"Could not discover any jukeboxes", nil)] autorelease];
 	}
 	
 	if (n == 0)
 	{
 		[self setStatus:STATUS_NO_NJB];
 		connected = NO;
-		return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:@"Could not locate any jukeboxes"] autorelease];
+		return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:NSLocalizedString(@"Could not locate any jukeboxes", nil)] autorelease];
 	}
 	
 	njb = &njbs[0];
@@ -368,7 +368,7 @@ StatusDisplayer *statusDisplayerGlobal;
 {
 	NSDate *date = [NSDate date];
 	if (![self isConnected])
-		return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:@"Not connected"] autorelease];
+		return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:NSLocalizedString(@"Not connected", nil)] autorelease];
 	
 	// set turbo on/off
 	[self enableTurbo];
@@ -396,7 +396,7 @@ StatusDisplayer *statusDisplayerGlobal;
 		[statusDisplayer postNotificationName:NOTIFICATION_TRACK_LIST_MODIFIED object:self];
 		
 		return [[[NJBTransactionResult alloc] initWithSuccess:YES
-																						 resultString:[NSString stringWithFormat:@"Speed %@ Mbps", [self rateString:rate]]] autorelease];
+																						 resultString:[NSString stringWithFormat:NSLocalizedString(@"Speed %@ Mbps", nil), [self rateString:rate]]] autorelease];
 	}
 }
 
@@ -461,7 +461,7 @@ StatusDisplayer *statusDisplayerGlobal;
 	double rate = ((double)[track filesize] / time) * 8.0 / (1024.0 * 1024.0);
 	
 	return [[[NJBTransactionResult alloc] initWithSuccess:YES
-																					 resultString:[NSString stringWithFormat:@"Speed %@ Mbps", [self rateString:rate]]] autorelease];
+																					 resultString:[NSString stringWithFormat:NSLocalizedString(@"Speed %@ Mbps", nil), [self rateString:rate]]] autorelease];
 }
 
 - (NSString *)uniqueFilename:(NSString *)path
@@ -592,7 +592,7 @@ StatusDisplayer *statusDisplayerGlobal;
 	double rate = ((double)[dataFile size] / time) * 8.0 / (1024.0 * 1024.0);
 		
 	return [[[NJBTransactionResult alloc] initWithSuccess:YES
-																					 resultString:[NSString stringWithFormat:@"Speed %@ Mbps", [self rateString:rate]]] autorelease];
+																					 resultString:[NSString stringWithFormat:NSLocalizedString(@"Speed %@ Mbps", nil), [self rateString:rate]]] autorelease];
 }
 
 - (NJBTransactionResult *)uploadFile:(DataFile *)dataFile toFolder:(NSString *)path
@@ -618,7 +618,7 @@ StatusDisplayer *statusDisplayerGlobal;
 		// rate in Mbps
 		double rate = ((double)[dataFile size] / time) * 8.0 / (1024.0 * 1024.0);
 		return [[[NJBTransactionResult alloc] initWithSuccess:YES
-																						 resultString:[NSString stringWithFormat:@"Speed %@ Mbps", [self rateString:rate]]] autorelease];
+																						 resultString:[NSString stringWithFormat:NSLocalizedString(@"Speed %@ Mbps", nil), [self rateString:rate]]] autorelease];
 	}
 }
 
@@ -965,10 +965,10 @@ int progress(u_int64_t sent, u_int64_t total, const char* buf, unsigned len, voi
 	BOOL powerConnected = (NJB_Get_Auxpower(njb) == 1);
 	
 	if (charging)
-		return @"Charging";
+		return NSLocalizedString(@"Charging", nil);
 	if (powerConnected)
-		return @"Battery charged or not present";
-	return @"Running off battery";
+		return NSLocalizedString(@"Battery charged or not present", nil);
+	return NSLocalizedString(@"Running off battery", nil);
 }
 
 - (void)enableTurbo
