@@ -138,7 +138,7 @@
 																							 withRunInMainThread:YES];
 	[updateTable setDisplayStatus:NO];
 	
-	NSString *description = @"Getting track list";
+	NSString *description = NSLocalizedString(@"Downloading Track List", nil);
 	[self addToQueue:getTracks withSubItems:[NSArray arrayWithObjects:updateTable, nil] withDescription:description];
 	[getTracks release];
 	[updateTable release];
@@ -186,7 +186,7 @@
 																							 withRunInMainThread:YES];
 	[allowNewPlaylist setDisplayStatus:NO];
 	
-	NSString *description = @"Getting playlists";
+	NSString *description = NSLocalizedString(@"Getting playlists", nil);
 	[self addToQueue:getPlaylists withSubItems:[NSArray arrayWithObjects:fillTrackInfo, updateTable, allowNewPlaylist, nil] withDescription:description];
 	[getPlaylists release];
 	[fillTrackInfo release];
@@ -238,7 +238,7 @@
 	NJBQueueItem *updatePlaylist = [[NJBQueueItem alloc] initWithTarget:theNJB withSelector:@selector(updatePlaylist:) withObject:playlist];
 	[updatePlaylist setStatus:STATUS_UPDATING_PLAYLIST];
 	
-	NSString *description = [NSString stringWithFormat:@"Updating playlist %@", [playlist name]];
+	NSString *description = [NSString stringWithFormat:NSLocalizedString(@"Updating playlist %@", nil), [playlist name]];
 	[self addToQueue:updatePlaylist withSubItems:nil withDescription:description];
 	[updatePlaylist release];
 }
@@ -250,7 +250,7 @@
 	NJBQueueItem *deletePlaylist = [[NJBQueueItem alloc] initWithTarget:theNJB withSelector:@selector(deletePlaylist:) withObject:playlist];
 	[deletePlaylist setStatus:STATUS_DELETING_PLAYLIST];
 	
-	NSString *description = [NSString stringWithFormat:@"Deleting playlist %@", [playlist name]];
+	NSString *description = [NSString stringWithFormat:NSLocalizedString(@"Deleting playlist %@", nil), [playlist name]];
 	[self addToQueue:deletePlaylist withSubItems:nil withDescription:description];
 	[deletePlaylist release];
 }
@@ -318,7 +318,10 @@
  */
 - (IBAction)deletePlaylist:(id)sender
 {
-	int result = NSRunAlertPanel(@"Playlist Deletion", @"Are you sure you want to delete the selected playlist off the NJB?", @"No", @"Yes", nil);
+	int result = NSRunAlertPanel(NSLocalizedString(@"Playlist Deletion", nil),
+															 NSLocalizedString(@"Are you sure you want to delete the selected playlist off the NJB?", nil),
+															 NSLocalizedString(@"No", nil),
+															 NSLocalizedString(@"Yes", nil), nil);
 	if (result == NSAlertDefaultReturn)
 		return;
 	
