@@ -214,6 +214,18 @@
 	[defaults setObject:[NSNumber numberWithInt:artistTol] forKey:PREF_KEY_DUPLICATES_ARTIST_TOL];
 }
 
+- (BOOL)turbo
+{
+	return [defaults boolForKey:PREF_KEY_TURBO];
+}
+
+- (void)setTurbo:(BOOL)turbo
+{
+	[defaults setObject:[NSNumber numberWithBool:turbo] forKey:PREF_KEY_TURBO];
+	
+	[theNJB setTurbo:turbo];
+}
+
 /**********************/
 
 - (void)registerDefaults
@@ -254,6 +266,8 @@
 	[defaultValues setObject:DEFAULT_DUPLICATES_TITLE_TOL forKey:PREF_KEY_DUPLICATES_TITLE_TOL];
 	// DUPLICATES_ARTIST_TOL
 	[defaultValues setObject:DEFAULT_DUPLICATES_ARTIST_TOL forKey:PREF_KEY_DUPLICATES_ARTIST_TOL];
+	// TURBO
+	[defaultValues setObject:DEFAULT_TURBO forKey:PREF_KEY_TURBO];
 	
 	[defaults registerDefaults:defaultValues];
 }
