@@ -25,6 +25,16 @@
 {
 	const char *uni = [str UTF8String];
 	unsigned short *uniShort = g_utf8_to_utf16(uni, -1, NULL, NULL);
+	
+	// we need byte swapping to build a Universal Binary
+	unsigned short *uniShortToSwap = uniShort;
+	
+	while (*uniShortToSwap != 0)
+	{
+		*uniShortToSwap = CFSwapInt16BigToHost(*uniShortToSwap);
+		uniShortToSwap++;
+	}
+		
 	return uniShort;
 }
 
