@@ -145,7 +145,16 @@ typedef unsigned __int64 u_int64_t;
 #define NJB_UC_UTF8     1 /**< libnjb to use Unicode UTF-8 */
 /** @} */
 
-#define OWNER_STRING_LENGTH	128 /**< The fixed length of the owner string */
+/**
+ * @defgroup turboflags Turbo flags
+ * @see NJB_Set_Turbo_Mode()
+ * @{
+ */
+#define NJB_TURBO_OFF   0 /**< turbo mode is off for series 3 devices */
+#define NJB_TURBO_ON    1 /**< turbo mode is on for series 3 devices */
+
+/** The fixed length of the owner string */
+#define OWNER_STRING_LENGTH	128
 /** A type defined for owner strings */
 typedef unsigned char owner_string[OWNER_STRING_LENGTH + 1];
 
@@ -456,6 +465,7 @@ int NJB_Get_SDMI_ID(njb_t *njb, u_int8_t *sdmiid);
 const char *NJB_Get_Device_Name(njb_t *njb, int type);
 int NJB_Get_Firmware_Revision(njb_t *njb, u_int8_t *major, u_int8_t *minor, u_int8_t *release);
 int NJB_Get_Hardware_Revision(njb_t *njb, u_int8_t *major, u_int8_t *minor, u_int8_t *release);
+int NJB_Set_Turbo_Mode(njb_t *njb, u_int8_t mode);
 /**
  * @}
  * @defgroup tagapi The track and tag (song ID metadata) manipulation API
