@@ -1,10 +1,6 @@
 #ifndef __NJBUSB__H
 #define __NJBUSB__H
 
-#ifndef HAVE_LIBUSB
-#define DEFAULT_DEV	"/dev/usb0"
-#endif
-
 #define NJB1_VENDOR_ID		0x0471
 #define NJB1_PRODUCT_ID		0x0222
 
@@ -41,6 +37,9 @@
 #define POCKETDJ_VENDOR_ID      0x041e
 #define POCKETDJ_PRODUCT_ID     0x4127
 
+#define ZENSLEEK_VENDOR_ID      0x041e
+#define ZENSLEEK_PRODUCT_ID     0x4136
+
 /*
  * Macros to detect certain features of the device
  * great for code readability.
@@ -55,7 +54,8 @@
          t == NJB_DEVICE_NJBZENTOUCH || \
 	 t == NJB_DEVICE_NJBZENMICRO || \
          t == NJB_DEVICE_DELLDJ2 || \
-         t == NJB_DEVICE_POCKETDJ )
+         t == NJB_DEVICE_POCKETDJ || \
+	 t == NJB_DEVICE_ZENSLEEK )
 
 #define PROTOCOL3_DEVICE(t) \
         (t == NJB_DEVICE_NJB2 || \
@@ -68,7 +68,8 @@
          t == NJB_DEVICE_NJBZENTOUCH || \
          t == NJB_DEVICE_NJBZENMICRO || \
          t == NJB_DEVICE_DELLDJ2 || \
-         t == NJB_DEVICE_POCKETDJ )
+         t == NJB_DEVICE_POCKETDJ || \
+	 t == NJB_DEVICE_ZENSLEEK )
 
 #endif
 
