@@ -486,6 +486,15 @@ void NJB_Reset_Get_Track_Tag (njb_t *njb)
  * first be rewound using the <code>NJB_Reset_Get_Track_Tag()</code>
  * function.
  *
+ * Notice that there is no function for getting the tag for a 
+ * <i>single</i> track, there is just this function that dumps out
+ * the entire database in one big go. The recommended approach is
+ * to keep an internal track cache of all tracks and use this for
+ * getting metadata for single tracks. There is as far as we know
+ * no function in the Creative firmwares for getting the metadata
+ * of a single track, so access through this function is the only
+ * option.
+ *
  * @param njb a pointer to the <code>njb_t</code> object to reset
  *            the track retrieveal pointer for
  * @return a track tag (song ID) or NULL if the last track tag
@@ -1013,7 +1022,7 @@ int NJB_Get_Track_fd (njb_t *njb, u_int32_t fileid, u_int32_t size,
     offset = 0;
     while (remain != 0 && !abortxfer) {
       /* Request as much as possible unless the last chunk is reached */
-      bsize= (remain > NJB_XFER_BLOCK_SIZE) ? NJB_XFER_BLOCK_SIZE : remain;
+      bsize = (remain > NJB_XFER_BLOCK_SIZE) ? NJB_XFER_BLOCK_SIZE : remain;
       
       bread = 0;
       
@@ -1078,6 +1087,7 @@ int NJB_Get_Track_fd (njb_t *njb, u_int32_t fileid, u_int32_t size,
   /* Protocol 3 series file transfer routine */
   if (PROTOCOL3_DEVICE(njb->device_type)) {
     int confirm_size;
+    njb3_state_t *state = (njb3_state_t *) njb->protocol_state;
     
     /* FIXME: add this and test. */
     /* njb3_ctrl_playing(njb, NJB3_STOP_PLAY); */
@@ -1104,23 +1114,22 @@ int NJB_Get_Track_fd (njb_t *njb, u_int32_t fileid, u_int32_t size,
        * indexed at an offset into the file. 
        */
       chunk_size = njb3_request_file_chunk(njb, fileid, offset);
-
-			if (chunk_size > remain)
-			{
-				printf("LIBNJB panic: chunk_size > remain, going to get whole chunk and see what happens\n");
-				
-				if (chunk_size == NJB3_CHUNK_SIZE)
-				{
-					size += (NJB3_CHUNK_SIZE) + 1 - remain;
-					remain = NJB3_CHUNK_SIZE + 1;
-				}
-				else
-				{
-					size += (chunk_size - remain);
-					remain = chunk_size;
-				}
-			}
-      else if ( chunk_size == -1 ) {
+      /*
+       * This addresses a particular problem exposed by the recordings
+       * made on the NJB3: files are reported as being smaller than
+       * they actually are. It is a firmware bug, but let's just work
+       * around it. (Fixed by Richard Low on 2005-09-22.)
+       */
+      if (chunk_size > remain) {
+	printf("LIBNJB panic: chunk_size > remain, going to get whole chunk and see what happens\n");
+	if (chunk_size == NJB3_CHUNK_SIZE) {
+	  size += (NJB3_CHUNK_SIZE) + 1 - remain;
+	  remain = NJB3_CHUNK_SIZE + 1;
+	} else {
+	  size += (chunk_size - remain);
+	  remain = chunk_size;
+	}
+      } else if ( chunk_size == -1 ) {
 	ret = -1;
 	goto clean_up_and_return;
       }
@@ -1132,21 +1141,26 @@ int NJB_Get_Track_fd (njb_t *njb, u_int32_t fileid, u_int32_t size,
       while (chunk_remain != 0) {
 	u_int32_t blocksize;
 
-#ifdef NO_TURBO
-	blocksize = NJB3_DEFAULT_GET_FILE_BLOCK_SIZE;
-#else
 	/*
-	 * This speed-up hack comes courtesy of Richard Low.
-	 * files of size 8192 or 8191 modulo 0x4000 are known to hang when 
-	 * downloading if request is 0x4000 bytes, so we avoid this 
-	 * scenario
+	 * This speed-up hack works on most devices but is
+	 * of course user-configurable.
 	 */
-	if (chunk_remain <= 0x2000U) {
-	  blocksize = 0x2000U;
+	if (state->turbo_mode == NJB_TURBO_OFF) {
+	  blocksize = NJB3_DEFAULT_GET_FILE_BLOCK_SIZE;
 	} else {
-	  blocksize = 0x4000U;
+	  /*
+	   * This speed-up hack comes courtesy of Richard Low.
+	   * files of size 8192 or 8191 modulo 0x4000 are known to hang when 
+	   * downloading if request is 0x4000 bytes, so we avoid this 
+	   * scenario
+	   */
+	  if (chunk_remain <= 0x2000U) {
+	    blocksize = 0x2000U;
+	  } else {
+	    blocksize = 0x4000U;
+	  }
 	}
-#endif
+
 	/*
 	 * Try to get maximum amount, if we run into a short 
 	 * read, that's OK 
@@ -1339,16 +1353,20 @@ static int send_file (njb_t *njb, const char *path, u_int64_t size,
     
     if (PROTOCOL3_DEVICE(njb->device_type)) {
       if (operation == 0) {
-#ifdef NO_TURBO
+/*
+ * This speed-up hack works on most devices but is
+ * of course user-configurable.
+ */
+njb3_state_t *state = (njb3_state_t *) njb->protocol_state;
+if (state->turbo_mode == NJB_TURBO_OFF)
 	maxblock = NJB3_DEFAULT_SEND_FILE_BLOCK_SIZE;
-#else
+else
 	/*
 	 * This hack courtesy of Richard Low.
 	 * Increasing the send max block by a factor of seven speeds up
 	 * transfers considerably.
 	 */
 	maxblock = 0xE000U;
-#endif
       } else if (operation == 1) {
 	maxblock = NJB3_FIRMWARE_CHUNK_SIZE;
       }
@@ -3408,7 +3426,11 @@ int NJB_Get_SDMI_ID(njb_t *njb, u_int8_t *sdmiid)
  * @param type decides whether libnjb should decide what kind of device
  *        this is, or if the string from the device itself should be
  *        used. 0 = use libnjb detection (based on USB device IDs),
- *        1 = get the string from the device itself.
+ *        1 = get the string from the device itself. If you set this
+ *        to type 1, you must first call <code>NJB_Open()</code> on
+ *        the <code>njb_t</code> object pointer, so this is not 
+ *        suitable when you want to display a selection list of available
+ *        devices prior to opening one of them.
  * @return a pointer to a string that contains the device 
  *        name string after a call to this function. The string 
  *        <b>must not</b> be freed by the caller, because this is a pointer 
@@ -3424,16 +3446,16 @@ const char *NJB_Get_Device_Name(njb_t *njb, int type)
   }
 
   if (type == 0) {
-    static char njb1str[] = "Nomad Jukebox 1";
-    static char njb2str[] = "Nomad Jukebox 2";
-    static char njb3str[] = "Nomad Jukebox 3";
-    static char njbzenstr[] = "Nomad Jukebox Zen";
-    static char njbzen2str[] = "Nomad Jukebox Zen USB 2.0";
-    static char njbzennxstr[] = "Nomad Jukebox Zen NX";
-    static char njbzenxtrastr[] = "Nomad Jukebox Zen Xtra";
+    static char njb1str[] = "NOMAD Jukebox (1)";
+    static char njb2str[] = "NOMAD Jukebox 2";
+    static char njb3str[] = "NOMAD Jukebox 3";
+    static char njbzenstr[] = "NOMAD Jukebox Zen";
+    static char njbzen2str[] = "NOMAD Jukebox Zen USB 2.0";
+    static char njbzennxstr[] = "NOMAD Jukebox Zen NX";
+    static char njbzenxtrastr[] = "NOMAD Jukebox Zen Xtra";
     static char njbdelldjstr[] = "Dell Digital Jukebox";
-    static char njbtouchstr[] = "Creative Jukebox Zen Touch";
-    static char njbmicrostr[] = "Creative Jukebox Zen Micro";
+    static char njbtouchstr[] = "Creative Zen Touch";
+    static char njbmicrostr[] = "Creative Zen Micro";
     static char njbdelldj2str[] = "Second Generation Dell DJ";
     static char njbdellpocketstr[] = "Dell Pocket DJ";
     static char njbzensleekstr[] = "Creative Zen Sleek";
@@ -3562,3 +3584,29 @@ int NJB_Get_Hardware_Revision(njb_t *njb, u_int8_t *major, u_int8_t *minor, u_in
   }
   return -1;
 }
+
+
+/**
+ * This function sets the turbo mode to on or off. The default
+ * value if the function is not calles is that turbo is ON.
+ * We have found that a few (very few) devices will react badly
+ * on turbo mode, resulting in bad transfers. This setting is
+ * only applicable on the series 3 devices, it will have no effect
+ * on the NJB1. (Command available as of libnjb 2.2.4.)
+ *
+ * @param njb a pointer to the <code>njb_t</code> object to set
+ *            the turbo mode for.
+ * @param mode the turbo mode. <code>NJB_TURBO_ON</code> or
+ *            <code>NJB_TURBO_OFF</code>.
+ * @return 0 if the call was successful, -1 on failure.
+ */
+int NJB_Set_Turbo_Mode(njb_t *njb, u_int8_t mode)
+{
+  /* The turbo mode setting is silently ignored for the NJB1 */
+  if (PROTOCOL3_DEVICE(njb->device_type)) {
+    njb3_state_t *state = (njb3_state_t *) njb->protocol_state;
+
+    state->turbo_mode = mode;
+  }
+  return 0;
+}
